pub struct DebugInitialConfiguredParentElement<'b, 'element, Configurer: ConfigureElements<ConfigType>, ConfigType: Clone + Serialize, List: Copy> { /* private fields */ }Expand description
Root debug wrapper used at the start of UiFn::draw_in.
Wrap the layout root ConfiguredParentElement and pass a mutable reference to the
declaration recorder. All child elements created via new_element
record Open
before delegating to the inner layout.
Implementations
Sourceimpl<'b, 'element, Configurer: ConfigureElements<ConfigType>, ConfigType: Clone + Serialize, List: Copy> DebugInitialConfiguredParentElement<'b, 'element, Configurer, ConfigType, List>
impl<'b, 'element, Configurer: ConfigureElements<ConfigType>, ConfigType: Clone + Serialize, List: Copy> DebugInitialConfiguredParentElement<'b, 'element, Configurer, ConfigType, List>
Sourcepub fn new(
internal: &'b mut ConfiguredParentElement<'element, Configurer, ConfigType>,
interface_recorder: &'b mut LeafedInterfaceDeclaration<ConfigType, List>,
) -> Self
pub fn new( internal: &'b mut ConfiguredParentElement<'element, Configurer, ConfigType>, interface_recorder: &'b mut LeafedInterfaceDeclaration<ConfigType, List>, ) -> Self
Creates a root wrapper that records into interface_recorder.
Sourcepub fn new_element(
&mut self,
) -> DebugOpenElement<'_, Configurer, ConfigType, List>where
Self: Sized,
pub fn new_element(
&mut self,
) -> DebugOpenElement<'_, Configurer, ConfigType, List>where
Self: Sized,
Opens a new child element, recording Open in the declaration stream.
Returns a DebugOpenElement that can be used to configure the new element.
Sourcepub fn close_element(self)
pub fn close_element(self)
Closes the root element and records Close in the declaration stream.
It is not strictly necessary to call this method; closing also occurs when the
wrapper is dropped after all child DebugOpenElement handles are released.