LeafedInterfaceInstructions

Struct LeafedInterfaceInstructions 

pub struct LeafedInterfaceInstructions<ConfigType, List: Copy> {
    pub instruction: ConfigType,
    pub list: List,
}
One instruction paired with the leaf type list used for replay dispatch.

Fields

instruction: ConfigType

The instruction being replayed.

list: List

Copy of the leaf type list carried through the iterator.