pub struct DebugOpenElement<'element, Configurer: ConfigureElements<ConfigType>, ConfigType: Clone + Serialize, List: Copy> { /* private fields */ }Expand description
Debug wrapper for an open element being configured.
Use set_config for parent configs and
set_leaf_config for leaf configs. Converting to a parent via
make_parent does not record an extra instruction.
Implementations
Sourceimpl<'element, ConfigType: Clone + Serialize, Configurer: ConfigureElements<ConfigType>, List: Copy> DebugOpenElement<'element, Configurer, ConfigType, List>
impl<'element, ConfigType: Clone + Serialize, Configurer: ConfigureElements<ConfigType>, List: Copy> DebugOpenElement<'element, Configurer, ConfigType, List>
Sourcepub fn set_config(&mut self, config: ConfigType)
pub fn set_config(&mut self, config: ConfigType)
Sets the element config, recording Configure and applying it to the live element.
Sourcepub fn make_parent(
self,
) -> DebugConfiguredParentElement<'element, Configurer, ConfigType, List>
pub fn make_parent( self, ) -> DebugConfiguredParentElement<'element, Configurer, ConfigType, List>
Converts this open element into a parent that can accept children.
Returns a DebugConfiguredParentElement wrapping the inner parent element.
Sourcepub fn close_element(self)
pub fn close_element(self)
Closes this open element.
Close is also recorded when this wrapper is dropped.
Sourcepub fn set_leaf_config<LeafConfig>(self, config: LeafConfig)where
Configurer: ConfigureLeafElements<LeafConfig>,
LeafConfig: Serialize,
pub fn set_leaf_config<LeafConfig>(self, config: LeafConfig)where
Configurer: ConfigureLeafElements<LeafConfig>,
LeafConfig: Serialize,
Sets a leaf-specific config, recording LeafConfig and applying it to the live element.
Consumes self because the inner OpenElement::set_leaf_config also consumes
the open handle.