Module layout_module_debugger

Module layout_module_debugger 

Capture and replay layout-module output for debugging.

Modules

capture
LayoutManager decorator that records layout output.
isolated_replay
Isolated layout-module replay without a full CotisApp.

Functions

load_computed_layout
Loads a vector of layout outputs from a JSON file.
store_computed_layout
Writes a vector of layout outputs to a JSON file.